// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	PhysicalConstants.h --- simple class holding physical constants
//
//	DESCRIPTION:
//		A simple class providing physical constants of relevance for CAL/OAL
//
//	CHANGE HISTORY:
//		UL, 2000-03-22: 1.0.0: - first version
//		UL, 2000-11-23: 1.1.0: - eVperAo -> eVtimesAo (better name)
//		UL, 2001-03-12: 1.2.0: - added PhysicalConstants::AU
//
//	AUTHOR:
//		U. Lammers, Thu Mar 23 14:38:23 MET 2000
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al.,
//
//	$Header: /sasbuild/repositories/sasdev/sas/packages/caloalutils/src/PhysicalConstants.h,v 1.9 2013/02/19 17:59:02 aibarra Exp $
//

#ifndef PHYSICAL_CONSTANTS_H
#define PHYSICAL_CONSTANTS_H

#include "Celestial.h"

class PhysicalConstants {
public:
	//
	//	Ref: Zombeck
	//
	/* AI gcc4 porting
	 * assignment of read-only variable ‘PhysicalConstants::eVtimesAo’ =>
	 * use the values in stead of the variables.
	 */
        #if __GNUC__ >= 6 
	  static constexpr double c= 2.99792458e+8,	// speed of light [m/s]
	  AU = 1.495978706910000e+11,	// Astronomical Unit [m]
	  h = 6.6260755e-34 ,			// Planck's constant [Js]
	  Ao = 1.e-10 ,				// Angstroem [m]
	  eVtoJ = 1.60217733e-19,		// J per eV [J/eV]
	  hbar = 6.6260755e-34/(2.*3.14159265358979323846),  // AI gcc4 porting M_TWO_PI removed and change it for its value...
	  //eVtimesAo = 6.6260755e-34*2.99792458e+8/1.e-10/1.60217733e-19, // h*c/Ao/eVtoJ [eV*Ang]approx:12398.134
	  //New values from http://physics.nist.gov/cuu/Constants/Table/allascii.txt
	  // 6.62606957e-34*2.99792458e+8/1.0e-10/1.602176565e-19 ~ 12398.4179687500
	  eVtimesAo = 12398.4191, //eV2Ang
 	  avogadro = 6.0221367e+23,	// Avogardo number [1/mol]
	  r0 = 2.81794092e-15;		// electron radius [m]
        #else
	  static const double c= 2.99792458e+8,	// speed of light [m/s]
	  AU = 1.495978706910000e+11,	// Astronomical Unit [m]
	  h = 6.6260755e-34 ,			// Planck's constant [Js]
	  Ao = 1.e-10 ,				// Angstroem [m]
	  eVtoJ = 1.60217733e-19,		// J per eV [J/eV]
	  hbar = 6.6260755e-34/(2.*3.14159265358979323846),  
	  eVtimesAo = 12398.4191, //eV2Ang
 	  avogadro = 6.0221367e+23,	// Avogardo number [1/mol]
	  r0 = 2.81794092e-15;		// electron radius [m]
        #endif
};

#endif
